TODO: rewrite slogan and remove repo name hyphen or rename game entirely.

<div align=center>
  <img src="https://github.com/Masbender/text-dungeon/assets/91911303/63d96f62-a73d-4d79-ae93-347dd9906034">
  <h1 align=center>textdungeon: suffer alone in your terminal!</h1>
</div>

## About
This is a game created by Matthew Bender that allows you to traverse a spoopy dungeon. yay!! Rewrite me please... Noah was here.

## Installation

### Python Pip
install from pypi
```sh
pip install textdungeon
```
then simply run with
```sh
textdungeon
```

### Windows
Download text-dungeon.exe from [latest](https://github.com/Masbender/text-dungeon/releases/latest)

